JOB_SUBMIT_EXAMPLE = """\
$ anyscale job submit --name my-job --wait -- python main.py
Output
(anyscale +1.0s) Submitting job with config JobConfig(name='my-job', image_uri=None, compute_config=None, env_vars=None, py_modules=None, cloud=None, project=None, ray_version=None, job_queue_config=None).
(anyscale +1.7s) Uploading local dir '.' to cloud storage.
(anyscale +2.6s) Including workspace-managed pip dependencies.
(anyscale +3.2s) Job 'my-job' submitted, ID: 'prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe'.
(anyscale +3.2s) View the job in the UI: https://console.anyscale.com/jobs/prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe
(anyscale +3.2s) Waiting for the job to run. Interrupting this command will not cancel the job.
(anyscale +3.5s) Waiting for job 'prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe' to reach target state SUCCEEDED, currently in state: STARTING
(anyscale +1m19.7s) Job 'prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe' transitioned from STARTING to SUCCEEDED
(anyscale +1m19.7s) Job 'prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe' reached target state, exiting
"""

JOB_STATUS_EXAMPLE = """\
$ anyscale job status -n my-job
id: prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe
name: my-job
state: STARTING
runs:
- name: raysubmit_ynxBVGT1SmzndiXL
  state: SUCCEEDED
"""

JOB_TERMINATE_EXAMPLE = """\
$ anyscale job terminate -n my-job
(anyscale +5.4s) Marked job 'my-job' for termination
(anyscale +5.4s) Query the status of the job with `anyscale job status --name my-job`.
"""

JOB_ARCHIVE_EXAMPLE = """\
$ anyscale job archive -n my-job
(anyscale +8.5s) Job prodjob_vzq2pvkzyz3c1jw55kl76h4dk1 is successfully archived.
"""

JOB_LOGS_EXAMPLE = """\
$ anyscale job logs -n my-job
2024-08-23 20:31:10,913 INFO job_manager.py:531 -- Runtime env is setting up.
hello world
"""

JOB_WAIT_EXAMPLE = """\
$ anyscale job wait -n my-job
(anyscale +5.7s) Waiting for job 'my-job' to reach target state SUCCEEDED, currently in state: STARTING
(anyscale +1m34.2s) Job 'my-job' transitioned from STARTING to SUCCEEDED
(anyscale +1m34.2s) Job 'my-job' reached target state, exiting
"""

JOB_LIST_EXAMPLE = """\
$ anyscale job list -n my-job
Output
View your Jobs in the UI at https://console.anyscale.com/jobs
JOBS:
NAME    ID                                    COST  PROJECT NAME    CLUSTER NAME                                    CURRENT STATE           CREATOR           ENTRYPOINT
my-job  prodjob_s9x4uzc5jnkt5z53g4tujb3y2e       0  default         cluster_for_prodjob_s9x4uzc5jnkt5z53g4tujb3y2e  SUCCESS                 doc@anyscale.com  python main.py
"""

SCHEDULE_APPLY_EXAMPLE = """\
$ anyscale schedule apply -n my-schedule -f my-schedule.yaml
(anyscale +0.5s) Applying schedule with config ScheduleConfig(job_config=JobConfig(name='my-schedule', image_uri=None, compute_config=None, env_vars=None, py_modules=None, cloud=None, project=None, ray_version=None, job_queue_config=None), cron_expression='0 0 * * * *', timezone='UTC').
(anyscale +2.3s) Uploading local dir '.' to cloud storage.
(anyscale +3.7s) Including workspace-managed pip dependencies.
(anyscale +4.9s) Schedule 'my-schedule' submitted, ID: 'cronjob_vrjrbwcnfjjid7fsld3sfkn8jz'.

$ cat my-schedule.yaml
timezone: local
cron_expression: 0 0 * * * *
job_config:
    name: my-job
    entrypoint: python main.py
    max_retries: 5
"""

SCHEDULE_LIST_EXAMPLE = """\
$ anyscale schedule list -n my-schedule
Output
+------------------------------------+-------------+---------------+-----------+-------------+------------------+------------+------------------+-----------------------+
| ID                                 | NAME        | DESCRIPTION   | PROJECT   | CRON        | NEXT TRIGGER     | TIMEZONE   | CREATOR          | LATEST EXECUTION ID   |
|------------------------------------+-------------+---------------+-----------+-------------+------------------+------------+------------------+-----------------------|
| cronjob_vrjrbwcnfjjid7fsld3sfkn8jz | my-schedule |               | default   | 0 0 * * * * | 2 hours from now | UTC        | doc@anyscale.com |                       |
+------------------------------------+-------------+---------------+-----------+-------------+------------------+------------+------------------+-----------------------+
"""

SCHEDULE_PAUSE_EXAMPLE = """\
$ anyscale schedule pause -n my-schedule
(anyscale +3.6s) Set schedule 'my-schedule' to state DISABLED
"""

SCHEDULE_RESUME_EXAMPLE = """\
$ anyscale schedule resume -n my-schedule
(anyscale +4.1s) Set schedule 'my-schedule' to state ENABLED
"""

SCHEDULE_STATUS_EXAMPLE = """\
$ anyscale schedule status -n my-schedule
id: cronjob_vrjrbwcnfjjid7fsld3sfkn8jz
name: my-schedule
state: ENABLED
"""

SCHEDULE_RUN_EXAMPLE = """\
$ anyscale schedule run -n my-schedule
(anyscale +2.5s) Triggered job for schedule 'my-schedule'.
"""

SCHEDULE_URL_EXAMPLE = """\
$ anyscale schedule url -n my-schedule
Output
(anyscale +2.3s) View your schedule at https://console.anyscale.com/scheduled-jobs/cronjob_7zj
"""



# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class OrganizationMarketingQuestions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'size': 'CompanySize',
        'workload': 'str',
        'tech_stack': 'str',
        'source': 'str'
    }

    attribute_map = {
        'size': 'size',
        'workload': 'workload',
        'tech_stack': 'tech_stack',
        'source': 'source'
    }

    def __init__(self, size=None, workload=None, tech_stack=None, source=None, local_vars_configuration=None):  # noqa: E501
        """OrganizationMarketingQuestions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._size = None
        self._workload = None
        self._tech_stack = None
        self._source = None
        self.discriminator = None

        if size is not None:
            self.size = size
        if workload is not None:
            self.workload = workload
        if tech_stack is not None:
            self.tech_stack = tech_stack
        if source is not None:
            self.source = source

    @property
    def size(self):
        """Gets the size of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The size of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: CompanySize
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this OrganizationMarketingQuestions.


        :param size: The size of this OrganizationMarketingQuestions.  # noqa: E501
        :type: CompanySize
        """

        self._size = size

    @property
    def workload(self):
        """Gets the workload of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The workload of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: str
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this OrganizationMarketingQuestions.


        :param workload: The workload of this OrganizationMarketingQuestions.  # noqa: E501
        :type: str
        """

        self._workload = workload

    @property
    def tech_stack(self):
        """Gets the tech_stack of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The tech_stack of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: str
        """
        return self._tech_stack

    @tech_stack.setter
    def tech_stack(self, tech_stack):
        """Sets the tech_stack of this OrganizationMarketingQuestions.


        :param tech_stack: The tech_stack of this OrganizationMarketingQuestions.  # noqa: E501
        :type: str
        """

        self._tech_stack = tech_stack

    @property
    def source(self):
        """Gets the source of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The source of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this OrganizationMarketingQuestions.


        :param source: The source of this OrganizationMarketingQuestions.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationMarketingQuestions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganizationMarketingQuestions):
            return True

        return self.to_dict() != other.to_dict()



from typing import Optional

from anyscale._private.anyscale_client import AnyscaleClientInterface
from anyscale._private.sdk.base_sdk import BaseSDK
from anyscale._private.sdk.timer import Timer
from anyscale.cli_logger import BlockLogger
from anyscale.client.openapi_client.models import (
    DeletedPlatformFineTunedModel,
    FineTunedModel,
)


class PrivateLLMModelsSDK(BaseSDK):
    def __init__(
        self,
        *,
        logger: Optional[BlockLogger] = None,
        client: Optional[AnyscaleClientInterface] = None,
        timer: Optional[Timer] = None,
    ):
        super().__init__(logger=logger, client=client, timer=timer)

    def list(
        self,
        *,
        cloud_id: Optional[str] = None,
        project_id: Optional[str] = None,
        max_items: int = 20,
    ):
        return self.client.list_finetuned_models(cloud_id, project_id, max_items)

    def get(
        self, *, model_id: Optional[str] = None, job_id: Optional[str] = None
    ) -> FineTunedModel:
        return self.client.get_finetuned_model(model_id, job_id)

    def delete(self, model_id) -> DeletedPlatformFineTunedModel:
        return self.client.delete_finetuned_model(model_id)



from typing import List, Optional

from anyscale.api_utils.common_utils import (
    get_current_workspace_id,
    source_cloud_id_and_project_id,
)
from anyscale.cli_logger import BlockLogger
from anyscale.client.openapi_client import (
    DeletedPlatformFineTunedModel,
    FineTunedModel,
    FinetunedmodelListResponse,
)
from anyscale.controllers.base_controller import BaseController


LIST_ENDPOINT_COUNT = 20


class ModelsController(BaseController):
    def __init__(
        self, log: Optional[BlockLogger] = None, initialize_auth_api_client: bool = True
    ):
        if log is None:
            log = BlockLogger()

        super().__init__(initialize_auth_api_client=initialize_auth_api_client)

        self.log = log
        self.log.open_block("Output")

    def get_model(
        self, model_id: Optional[str], job_id: Optional[str]
    ) -> FineTunedModel:
        """Retrieves model information given model id"""
        if model_id:
            return self.api_client.get_model_api_v2_llm_models_model_id_get(
                model_id
            ).result
        elif job_id:
            return self.api_client.get_model_by_job_id_api_v2_llm_models_get_by_job_id_job_id_get(
                job_id
            ).result
        else:
            raise ValueError("Atleast one of `model-id` or `job-id` should be provided")

    def delete_model(self, model_id: str) -> DeletedPlatformFineTunedModel:
        return self.api_client.delete_model_api_v2_llm_models_model_id_delete(
            model_id
        ).result

    def list_models(
        self, *, cloud_id: Optional[str], project_id: Optional[str], max_items: int
    ) -> List[FineTunedModel]:
        """Lists fine-tuned models optionally filtered by `cloud_id` and `project_id`"""
        if get_current_workspace_id() is not None:
            # Resolve `cloud_id` and `project_id`. If not provided and if this is being run in a workspace,
            # we use the `cloud_id` and `project_id` of the workspace
            cloud_id, project_id = source_cloud_id_and_project_id(
                internal_api=self.api_client,
                external_api=self.anyscale_api_client,
                cloud_id=cloud_id,
                project_id=project_id,
            )
        paging_token = None
        results = []
        while True:
            count = min(LIST_ENDPOINT_COUNT, max_items)
            resp: FinetunedmodelListResponse = self.api_client.list_models_api_v2_llm_models_get(
                cloud_id=cloud_id,
                project_id=project_id,
                paging_token=paging_token,
                count=count,
            )
            models = resp.results
            results.extend(models)
            if not len(models) or not resp.metadata.next_paging_token:
                break

            if max_items and len(results) >= max_items:
                break
            paging_token = resp.metadata.next_paging_token

        return results[:max_items] if max_items else results
